#coding:utf-8


class Icons:
    """
    Статический класс, который включает пак набора иконок и дефолтные иконки m3
    """
    # дефолтные иконки m3
    M3_ADD = 'add_item'
    M3_EDIT = 'edit_item'
    M3_DELETE = 'delete_item'
    M3_SEARCH = 'search'

    # Сгенерированный набор иконок
    ACCEPT = 'icon-accept'
    ADD = 'icon-add'
    ANCHOR = 'icon-anchor'
    APPLICATION = 'icon-application'
    APPLICATION_ADD = 'icon-application-add'
    APPLICATION_CASCADE = 'icon-application-cascade'
    APPLICATION_DELETE = 'icon-application-delete'
    APPLICATION_DOUBLE = 'icon-application-double'
    APPLICATION_EDIT = 'icon-application-edit'
    APPLICATION_ERROR = 'icon-application-error'
    APPLICATION_FORM = 'icon-application-form'
    APPLICATION_FORM_ADD = 'icon-application-form-add'
    APPLICATION_FORM_DELETE = 'icon-application-form-delete'
    APPLICATION_FORM_EDIT = 'icon-application-form-edit'
    APPLICATION_FORM_MAGNIFY = 'icon-application-form-magnify'
    APPLICATION_GET = 'icon-application-get'
    APPLICATION_GO = 'icon-application-go'
    APPLICATION_HOME = 'icon-application-home'
    APPLICATION_KEY = 'icon-application-key'
    APPLICATION_LIGHTNING = 'icon-application-lightning'
    APPLICATION_LINK = 'icon-application-link'
    APPLICATION_OSX = 'icon-application-osx'
    APPLICATION_OSX_TERMINAL = 'icon-application-osx-terminal'
    APPLICATION_PUT = 'icon-application-put'
    APPLICATION_SIDE_BOXES = 'icon-application-side-boxes'
    APPLICATION_SIDE_CONTRACT = 'icon-application-side-contract'
    APPLICATION_SIDE_EXPAND = 'icon-application-side-expand'
    APPLICATION_SIDE_LIST = 'icon-application-side-list'
    APPLICATION_SIDE_TREE = 'icon-application-side-tree'
    APPLICATION_SPLIT = 'icon-application-split'
    APPLICATION_TILE_HORIZONTAL = 'icon-application-tile-horizontal'
    APPLICATION_TILE_VERTICAL = 'icon-application-tile-vertical'
    APPLICATION_VIEW_COLUMNS = 'icon-application-view-columns'
    APPLICATION_VIEW_DETAIL = 'icon-application-view-detail'
    APPLICATION_VIEW_GALLERY = 'icon-application-view-gallery'
    APPLICATION_VIEW_ICONS = 'icon-application-view-icons'
    APPLICATION_VIEW_LIST = 'icon-application-view-list'
    APPLICATION_VIEW_TILE = 'icon-application-view-tile'
    APPLICATION_XP = 'icon-application-xp'
    APPLICATION_XP_TERMINAL = 'icon-application-xp-terminal'
    ARROW_BRANCH = 'icon-arrow-branch'
    ARROW_DIVIDE = 'icon-arrow-divide'
    ARROW_DOWN = 'icon-arrow-down'
    ARROW_IN = 'icon-arrow-in'
    ARROW_INOUT = 'icon-arrow-inout'
    ARROW_JOIN = 'icon-arrow-join'
    ARROW_LEFT = 'icon-arrow-left'
    ARROW_MERGE = 'icon-arrow-merge'
    ARROW_OUT = 'icon-arrow-out'
    ARROW_REDO = 'icon-arrow-redo'
    ARROW_REFRESH = 'icon-arrow-refresh'
    ARROW_REFRESH_SMALL = 'icon-arrow-refresh-small'
    ARROW_RIGHT = 'icon-arrow-right'
    ARROW_ROTATE_ANTICLOCKWISE = 'icon-arrow-rotate-anticlockwise'
    ARROW_ROTATE_CLOCKWISE = 'icon-arrow-rotate-clockwise'
    ARROW_SWITCH = 'icon-arrow-switch'
    ARROW_TURN_LEFT = 'icon-arrow-turn-left'
    ARROW_TURN_RIGHT = 'icon-arrow-turn-right'
    ARROW_UNDO = 'icon-arrow-undo'
    ARROW_UP = 'icon-arrow-up'
    ASTERISK_ORANGE = 'icon-asterisk-orange'
    ASTERISK_YELLOW = 'icon-asterisk-yellow'
    ATTACH = 'icon-attach'
    AWARD_STAR_ADD = 'icon-award-star-add'
    AWARD_STAR_BRONZE_1 = 'icon-award-star-bronze-1'
    AWARD_STAR_BRONZE_2 = 'icon-award-star-bronze-2'
    AWARD_STAR_BRONZE_3 = 'icon-award-star-bronze-3'
    AWARD_STAR_DELETE = 'icon-award-star-delete'
    AWARD_STAR_GOLD_1 = 'icon-award-star-gold-1'
    AWARD_STAR_GOLD_2 = 'icon-award-star-gold-2'
    AWARD_STAR_GOLD_3 = 'icon-award-star-gold-3'
    AWARD_STAR_SILVER_1 = 'icon-award-star-silver-1'
    AWARD_STAR_SILVER_2 = 'icon-award-star-silver-2'
    AWARD_STAR_SILVER_3 = 'icon-award-star-silver-3'
    BASKET = 'icon-basket'
    BASKET_ADD = 'icon-basket-add'
    BASKET_DELETE = 'icon-basket-delete'
    BASKET_EDIT = 'icon-basket-edit'
    BASKET_ERROR = 'icon-basket-error'
    BASKET_GO = 'icon-basket-go'
    BASKET_PUT = 'icon-basket-put'
    BASKET_REMOVE = 'icon-basket-remove'
    BELL = 'icon-bell'
    BELL_ADD = 'icon-bell-add'
    BELL_DELETE = 'icon-bell-delete'
    BELL_ERROR = 'icon-bell-error'
    BELL_GO = 'icon-bell-go'
    BELL_LINK = 'icon-bell-link'
    BIN = 'icon-bin'
    BIN_CLOSED = 'icon-bin-closed'
    BIN_EMPTY = 'icon-bin-empty'
    BOMB = 'icon-bomb'
    BOOK = 'icon-book'
    BOOK_ADD = 'icon-book-add'
    BOOK_ADDRESSES = 'icon-book-addresses'
    BOOK_DELETE = 'icon-book-delete'
    BOOK_EDIT = 'icon-book-edit'
    BOOK_ERROR = 'icon-book-error'
    BOOK_GO = 'icon-book-go'
    BOOK_KEY = 'icon-book-key'
    BOOK_LINK = 'icon-book-link'
    BOOK_NEXT = 'icon-book-next'
    BOOK_OPEN = 'icon-book-open'
    BOOK_PREVIOUS = 'icon-book-previous'
    BOX = 'icon-box'
    BRICK = 'icon-brick'
    BRICKS = 'icon-bricks'
    BRICK_ADD = 'icon-brick-add'
    BRICK_DELETE = 'icon-brick-delete'
    BRICK_EDIT = 'icon-brick-edit'
    BRICK_ERROR = 'icon-brick-error'
    BRICK_GO = 'icon-brick-go'
    BRICK_LINK = 'icon-brick-link'
    BRIEFCASE = 'icon-briefcase'
    BUG = 'icon-bug'
    BUG_ADD = 'icon-bug-add'
    BUG_DELETE = 'icon-bug-delete'
    BUG_EDIT = 'icon-bug-edit'
    BUG_ERROR = 'icon-bug-error'
    BUG_GO = 'icon-bug-go'
    BUG_LINK = 'icon-bug-link'
    BUILDING = 'icon-building'
    BUILDING_ADD = 'icon-building-add'
    BUILDING_DELETE = 'icon-building-delete'
    BUILDING_EDIT = 'icon-building-edit'
    BUILDING_ERROR = 'icon-building-error'
    BUILDING_GO = 'icon-building-go'
    BUILDING_KEY = 'icon-building-key'
    BUILDING_LINK = 'icon-building-link'
    BULLET_ADD = 'icon-bullet-add'
    BULLET_ARROW_BOTTOM = 'icon-bullet-arrow-bottom'
    BULLET_ARROW_DOWN = 'icon-bullet-arrow-down'
    BULLET_ARROW_TOP = 'icon-bullet-arrow-top'
    BULLET_ARROW_UP = 'icon-bullet-arrow-up'
    BULLET_BLACK = 'icon-bullet-black'
    BULLET_BLUE = 'icon-bullet-blue'
    BULLET_DELETE = 'icon-bullet-delete'
    BULLET_DISK = 'icon-bullet-disk'
    BULLET_ERROR = 'icon-bullet-error'
    BULLET_FEED = 'icon-bullet-feed'
    BULLET_GO = 'icon-bullet-go'
    BULLET_GREEN = 'icon-bullet-green'
    BULLET_KEY = 'icon-bullet-key'
    BULLET_ORANGE = 'icon-bullet-orange'
    BULLET_PICTURE = 'icon-bullet-picture'
    BULLET_PINK = 'icon-bullet-pink'
    BULLET_PURPLE = 'icon-bullet-purple'
    BULLET_RED = 'icon-bullet-red'
    BULLET_STAR = 'icon-bullet-star'
    BULLET_TOGGLE_MINUS = 'icon-bullet-toggle-minus'
    BULLET_TOGGLE_PLUS = 'icon-bullet-toggle-plus'
    BULLET_WHITE = 'icon-bullet-white'
    BULLET_WRENCH = 'icon-bullet-wrench'
    BULLET_YELLOW = 'icon-bullet-yellow'
    CAKE = 'icon-cake'
    CALCULATOR = 'icon-calculator'
    CALCULATOR_ADD = 'icon-calculator-add'
    CALCULATOR_DELETE = 'icon-calculator-delete'
    CALCULATOR_EDIT = 'icon-calculator-edit'
    CALCULATOR_ERROR = 'icon-calculator-error'
    CALCULATOR_LINK = 'icon-calculator-link'
    CALENDAR = 'icon-calendar'
    CALENDAR_ADD = 'icon-calendar-add'
    CALENDAR_DELETE = 'icon-calendar-delete'
    CALENDAR_EDIT = 'icon-calendar-edit'
    CALENDAR_LINK = 'icon-calendar-link'
    CALENDAR_VIEW_DAY = 'icon-calendar-view-day'
    CALENDAR_VIEW_MONTH = 'icon-calendar-view-month'
    CALENDAR_VIEW_WEEK = 'icon-calendar-view-week'
    CAMERA = 'icon-camera'
    CAMERA_ADD = 'icon-camera-add'
    CAMERA_DELETE = 'icon-camera-delete'
    CAMERA_EDIT = 'icon-camera-edit'
    CAMERA_ERROR = 'icon-camera-error'
    CAMERA_GO = 'icon-camera-go'
    CAMERA_LINK = 'icon-camera-link'
    CAMERA_SMALL = 'icon-camera-small'
    CANCEL = 'icon-cancel'
    CAR = 'icon-car'
    CART = 'icon-cart'
    CART_ADD = 'icon-cart-add'
    CART_DELETE = 'icon-cart-delete'
    CART_EDIT = 'icon-cart-edit'
    CART_ERROR = 'icon-cart-error'
    CART_GO = 'icon-cart-go'
    CART_PUT = 'icon-cart-put'
    CART_REMOVE = 'icon-cart-remove'
    CAR_ADD = 'icon-car-add'
    CAR_DELETE = 'icon-car-delete'
    CD = 'icon-cd'
    CD_ADD = 'icon-cd-add'
    CD_BURN = 'icon-cd-burn'
    CD_DELETE = 'icon-cd-delete'
    CD_EDIT = 'icon-cd-edit'
    CD_EJECT = 'icon-cd-eject'
    CD_GO = 'icon-cd-go'
    CHART_BAR = 'icon-chart-bar'
    CHART_BAR_ADD = 'icon-chart-bar-add'
    CHART_BAR_DELETE = 'icon-chart-bar-delete'
    CHART_BAR_EDIT = 'icon-chart-bar-edit'
    CHART_BAR_ERROR = 'icon-chart-bar-error'
    CHART_BAR_LINK = 'icon-chart-bar-link'
    CHART_CURVE = 'icon-chart-curve'
    CHART_CURVE_ADD = 'icon-chart-curve-add'
    CHART_CURVE_DELETE = 'icon-chart-curve-delete'
    CHART_CURVE_EDIT = 'icon-chart-curve-edit'
    CHART_CURVE_ERROR = 'icon-chart-curve-error'
    CHART_CURVE_GO = 'icon-chart-curve-go'
    CHART_CURVE_LINK = 'icon-chart-curve-link'
    CHART_LINE = 'icon-chart-line'
    CHART_LINE_ADD = 'icon-chart-line-add'
    CHART_LINE_DELETE = 'icon-chart-line-delete'
    CHART_LINE_EDIT = 'icon-chart-line-edit'
    CHART_LINE_ERROR = 'icon-chart-line-error'
    CHART_LINE_LINK = 'icon-chart-line-link'
    CHART_ORGANISATION = 'icon-chart-organisation'
    CHART_ORGANISATION_ADD = 'icon-chart-organisation-add'
    CHART_ORGANISATION_DELETE = 'icon-chart-organisation-delete'
    CHART_PIE = 'icon-chart-pie'
    CHART_PIE_ADD = 'icon-chart-pie-add'
    CHART_PIE_DELETE = 'icon-chart-pie-delete'
    CHART_PIE_EDIT = 'icon-chart-pie-edit'
    CHART_PIE_ERROR = 'icon-chart-pie-error'
    CHART_PIE_LINK = 'icon-chart-pie-link'
    CLOCK = 'icon-clock'
    CLOCK_ADD = 'icon-clock-add'
    CLOCK_DELETE = 'icon-clock-delete'
    CLOCK_EDIT = 'icon-clock-edit'
    CLOCK_ERROR = 'icon-clock-error'
    CLOCK_GO = 'icon-clock-go'
    CLOCK_LINK = 'icon-clock-link'
    CLOCK_PAUSE = 'icon-clock-pause'
    CLOCK_PLAY = 'icon-clock-play'
    CLOCK_RED = 'icon-clock-red'
    CLOCK_STOP = 'icon-clock-stop'
    COG = 'icon-cog'
    COG_ADD = 'icon-cog-add'
    COG_DELETE = 'icon-cog-delete'
    COG_EDIT = 'icon-cog-edit'
    COG_ERROR = 'icon-cog-error'
    COG_GO = 'icon-cog-go'
    COINS = 'icon-coins'
    COINS_ADD = 'icon-coins-add'
    COINS_DELETE = 'icon-coins-delete'
    COLOR_SWATCH = 'icon-color-swatch'
    COLOR_WHEEL = 'icon-color-wheel'
    COMMENT = 'icon-comment'
    COMMENTS = 'icon-comments'
    COMMENTS_ADD = 'icon-comments-add'
    COMMENTS_DELETE = 'icon-comments-delete'
    COMMENT_ADD = 'icon-comment-add'
    COMMENT_DELETE = 'icon-comment-delete'
    COMMENT_EDIT = 'icon-comment-edit'
    COMPRESS = 'icon-compress'
    COMPUTER = 'icon-computer'
    COMPUTER_ADD = 'icon-computer-add'
    COMPUTER_DELETE = 'icon-computer-delete'
    COMPUTER_EDIT = 'icon-computer-edit'
    COMPUTER_ERROR = 'icon-computer-error'
    COMPUTER_GO = 'icon-computer-go'
    COMPUTER_KEY = 'icon-computer-key'
    COMPUTER_LINK = 'icon-computer-link'
    CONNECT = 'icon-connect'
    CONTRAST = 'icon-contrast'
    CONTRAST_DECREASE = 'icon-contrast-decrease'
    CONTRAST_HIGH = 'icon-contrast-high'
    CONTRAST_INCREASE = 'icon-contrast-increase'
    CONTRAST_LOW = 'icon-contrast-low'
    CONTROLLER = 'icon-controller'
    CONTROLLER_ADD = 'icon-controller-add'
    CONTROLLER_DELETE = 'icon-controller-delete'
    CONTROLLER_ERROR = 'icon-controller-error'
    CONTROL_EJECT = 'icon-control-eject'
    CONTROL_EJECT_BLUE = 'icon-control-eject-blue'
    CONTROL_END = 'icon-control-end'
    CONTROL_END_BLUE = 'icon-control-end-blue'
    CONTROL_EQUALIZER = 'icon-control-equalizer'
    CONTROL_EQUALIZER_BLUE = 'icon-control-equalizer-blue'
    CONTROL_FASTFORWARD = 'icon-control-fastforward'
    CONTROL_FASTFORWARD_BLUE = 'icon-control-fastforward-blue'
    CONTROL_PAUSE = 'icon-control-pause'
    CONTROL_PAUSE_BLUE = 'icon-control-pause-blue'
    CONTROL_PLAY = 'icon-control-play'
    CONTROL_PLAY_BLUE = 'icon-control-play-blue'
    CONTROL_REPEAT = 'icon-control-repeat'
    CONTROL_REPEAT_BLUE = 'icon-control-repeat-blue'
    CONTROL_REWIND = 'icon-control-rewind'
    CONTROL_REWIND_BLUE = 'icon-control-rewind-blue'
    CONTROL_START = 'icon-control-start'
    CONTROL_START_BLUE = 'icon-control-start-blue'
    CONTROL_STOP = 'icon-control-stop'
    CONTROL_STOP_BLUE = 'icon-control-stop-blue'
    CREDITCARDS = 'icon-creditcards'
    CROSS = 'icon-cross'
    CSS = 'icon-css'
    CSS_ADD = 'icon-css-add'
    CSS_DELETE = 'icon-css-delete'
    CSS_GO = 'icon-css-go'
    CSS_VALID = 'icon-css-valid'
    CUP = 'icon-cup'
    CUP_ADD = 'icon-cup-add'
    CUP_DELETE = 'icon-cup-delete'
    CUP_EDIT = 'icon-cup-edit'
    CUP_ERROR = 'icon-cup-error'
    CUP_GO = 'icon-cup-go'
    CUP_KEY = 'icon-cup-key'
    CUP_LINK = 'icon-cup-link'
    CURSOR = 'icon-cursor'
    CUT = 'icon-cut'
    CUT_RED = 'icon-cut-red'
    DATABASE = 'icon-database'
    DATABASE_ADD = 'icon-database-add'
    DATABASE_CONNECT = 'icon-database-connect'
    DATABASE_DELETE = 'icon-database-delete'
    DATABASE_EDIT = 'icon-database-edit'
    DATABASE_ERROR = 'icon-database-error'
    DATABASE_GEAR = 'icon-database-gear'
    DATABASE_GO = 'icon-database-go'
    DATABASE_KEY = 'icon-database-key'
    DATABASE_LIGHTNING = 'icon-database-lightning'
    DATABASE_LINK = 'icon-database-link'
    DATABASE_REFRESH = 'icon-database-refresh'
    DATABASE_SAVE = 'icon-database-save'
    DATABASE_TABLE = 'icon-database-table'
    DATE = 'icon-date'
    DATE_ADD = 'icon-date-add'
    DATE_DELETE = 'icon-date-delete'
    DATE_EDIT = 'icon-date-edit'
    DATE_ERROR = 'icon-date-error'
    DATE_GO = 'icon-date-go'
    DATE_LINK = 'icon-date-link'
    DATE_MAGNIFY = 'icon-date-magnify'
    DATE_NEXT = 'icon-date-next'
    DATE_PREVIOUS = 'icon-date-previous'
    DELETE = 'icon-delete'
    DISCONNECT = 'icon-disconnect'
    DISK = 'icon-disk'
    DISK_MULTIPLE = 'icon-disk-multiple'
    DOOR = 'icon-door'
    DOOR_IN = 'icon-door-in'
    DOOR_OPEN = 'icon-door-open'
    DOOR_OUT = 'icon-door-out'
    DRINK = 'icon-drink'
    DRINK_EMPTY = 'icon-drink-empty'
    DRIVE = 'icon-drive'
    DRIVE_ADD = 'icon-drive-add'
    DRIVE_BURN = 'icon-drive-burn'
    DRIVE_CD = 'icon-drive-cd'
    DRIVE_CD_EMPTY = 'icon-drive-cd-empty'
    DRIVE_DELETE = 'icon-drive-delete'
    DRIVE_DISK = 'icon-drive-disk'
    DRIVE_EDIT = 'icon-drive-edit'
    DRIVE_ERROR = 'icon-drive-error'
    DRIVE_GO = 'icon-drive-go'
    DRIVE_KEY = 'icon-drive-key'
    DRIVE_LINK = 'icon-drive-link'
    DRIVE_MAGNIFY = 'icon-drive-magnify'
    DRIVE_NETWORK = 'icon-drive-network'
    DRIVE_RENAME = 'icon-drive-rename'
    DRIVE_USER = 'icon-drive-user'
    DRIVE_WEB = 'icon-drive-web'
    DVD = 'icon-dvd'
    DVD_ADD = 'icon-dvd-add'
    DVD_DELETE = 'icon-dvd-delete'
    DVD_EDIT = 'icon-dvd-edit'
    DVD_ERROR = 'icon-dvd-error'
    DVD_GO = 'icon-dvd-go'
    DVD_KEY = 'icon-dvd-key'
    DVD_LINK = 'icon-dvd-link'
    EMAIL = 'icon-email'
    EMAIL_ADD = 'icon-email-add'
    EMAIL_ATTACH = 'icon-email-attach'
    EMAIL_DELETE = 'icon-email-delete'
    EMAIL_EDIT = 'icon-email-edit'
    EMAIL_ERROR = 'icon-email-error'
    EMAIL_GO = 'icon-email-go'
    EMAIL_LINK = 'icon-email-link'
    EMAIL_OPEN = 'icon-email-open'
    EMAIL_OPEN_IMAGE = 'icon-email-open-image'
    EMOTICON_EVILGRIN = 'icon-emoticon-evilgrin'
    EMOTICON_GRIN = 'icon-emoticon-grin'
    EMOTICON_HAPPY = 'icon-emoticon-happy'
    EMOTICON_SMILE = 'icon-emoticon-smile'
    EMOTICON_SURPRISED = 'icon-emoticon-surprised'
    EMOTICON_TONGUE = 'icon-emoticon-tongue'
    EMOTICON_UNHAPPY = 'icon-emoticon-unhappy'
    EMOTICON_WAII = 'icon-emoticon-waii'
    EMOTICON_WINK = 'icon-emoticon-wink'
    ERROR = 'icon-error'
    ERROR_ADD = 'icon-error-add'
    ERROR_DELETE = 'icon-error-delete'
    ERROR_GO = 'icon-error-go'
    EXCLAMATION = 'icon-exclamation'
    EYE = 'icon-eye'
    FEED = 'icon-feed'
    FEED_ADD = 'icon-feed-add'
    FEED_DELETE = 'icon-feed-delete'
    FEED_DISK = 'icon-feed-disk'
    FEED_EDIT = 'icon-feed-edit'
    FEED_ERROR = 'icon-feed-error'
    FEED_GO = 'icon-feed-go'
    FEED_KEY = 'icon-feed-key'
    FEED_LINK = 'icon-feed-link'
    FEED_MAGNIFY = 'icon-feed-magnify'
    FEMALE = 'icon-female'
    FILM = 'icon-film'
    FILM_ADD = 'icon-film-add'
    FILM_DELETE = 'icon-film-delete'
    FILM_EDIT = 'icon-film-edit'
    FILM_ERROR = 'icon-film-error'
    FILM_GO = 'icon-film-go'
    FILM_KEY = 'icon-film-key'
    FILM_LINK = 'icon-film-link'
    FILM_SAVE = 'icon-film-save'
    FIND = 'icon-find'
    FLAG_BLUE = 'icon-flag-blue'
    FLAG_GREEN = 'icon-flag-green'
    FLAG_ORANGE = 'icon-flag-orange'
    FLAG_PINK = 'icon-flag-pink'
    FLAG_PURPLE = 'icon-flag-purple'
    FLAG_RED = 'icon-flag-red'
    FLAG_YELLOW = 'icon-flag-yellow'
    FOLDER = 'icon-folder'
    FOLDER_ADD = 'icon-folder-add'
    FOLDER_BELL = 'icon-folder-bell'
    FOLDER_BRICK = 'icon-folder-brick'
    FOLDER_BUG = 'icon-folder-bug'
    FOLDER_CAMERA = 'icon-folder-camera'
    FOLDER_DATABASE = 'icon-folder-database'
    FOLDER_DELETE = 'icon-folder-delete'
    FOLDER_EDIT = 'icon-folder-edit'
    FOLDER_ERROR = 'icon-folder-error'
    FOLDER_EXPLORE = 'icon-folder-explore'
    FOLDER_FEED = 'icon-folder-feed'
    FOLDER_FIND = 'icon-folder-find'
    FOLDER_GO = 'icon-folder-go'
    FOLDER_HEART = 'icon-folder-heart'
    FOLDER_IMAGE = 'icon-folder-image'
    FOLDER_KEY = 'icon-folder-key'
    FOLDER_LIGHTBULB = 'icon-folder-lightbulb'
    FOLDER_LINK = 'icon-folder-link'
    FOLDER_MAGNIFY = 'icon-folder-magnify'
    FOLDER_PAGE = 'icon-folder-page'
    FOLDER_PAGE_WHITE = 'icon-folder-page-white'
    FOLDER_PALETTE = 'icon-folder-palette'
    FOLDER_PICTURE = 'icon-folder-picture'
    FOLDER_STAR = 'icon-folder-star'
    FOLDER_TABLE = 'icon-folder-table'
    FOLDER_USER = 'icon-folder-user'
    FOLDER_WRENCH = 'icon-folder-wrench'
    FONT = 'icon-font'
    FONT_ADD = 'icon-font-add'
    FONT_DELETE = 'icon-font-delete'
    FONT_GO = 'icon-font-go'
    GROUP = 'icon-group'
    GROUP_ADD = 'icon-group-add'
    GROUP_DELETE = 'icon-group-delete'
    GROUP_EDIT = 'icon-group-edit'
    GROUP_ERROR = 'icon-group-error'
    GROUP_GEAR = 'icon-group-gear'
    GROUP_GO = 'icon-group-go'
    GROUP_KEY = 'icon-group-key'
    GROUP_LINK = 'icon-group-link'
    HEART = 'icon-heart'
    HEART_ADD = 'icon-heart-add'
    HEART_DELETE = 'icon-heart-delete'
    HELP = 'icon-help'
    HOURGLASS = 'icon-hourglass'
    HOURGLASS_ADD = 'icon-hourglass-add'
    HOURGLASS_DELETE = 'icon-hourglass-delete'
    HOURGLASS_GO = 'icon-hourglass-go'
    HOURGLASS_LINK = 'icon-hourglass-link'
    HOUSE = 'icon-house'
    HOUSE_GO = 'icon-house-go'
    HOUSE_LINK = 'icon-house-link'
    HTML = 'icon-html'
    HTML_ADD = 'icon-html-add'
    HTML_DELETE = 'icon-html-delete'
    HTML_GO = 'icon-html-go'
    HTML_VALID = 'icon-html-valid'
    IMAGE = 'icon-image'
    IMAGES = 'icon-images'
    IMAGE_ADD = 'icon-image-add'
    IMAGE_DELETE = 'icon-image-delete'
    IMAGE_EDIT = 'icon-image-edit'
    IMAGE_LINK = 'icon-image-link'
    INFORMATION = 'icon-information'
    IPOD = 'icon-ipod'
    IPOD_CAST = 'icon-ipod-cast'
    IPOD_CAST_ADD = 'icon-ipod-cast-add'
    IPOD_CAST_DELETE = 'icon-ipod-cast-delete'
    IPOD_SOUND = 'icon-ipod-sound'
    JOYSTICK = 'icon-joystick'
    JOYSTICK_ADD = 'icon-joystick-add'
    JOYSTICK_DELETE = 'icon-joystick-delete'
    JOYSTICK_ERROR = 'icon-joystick-error'
    KEY = 'icon-key'
    KEYBOARD = 'icon-keyboard'
    KEYBOARD_ADD = 'icon-keyboard-add'
    KEYBOARD_DELETE = 'icon-keyboard-delete'
    KEYBOARD_MAGNIFY = 'icon-keyboard-magnify'
    KEY_ADD = 'icon-key-add'
    KEY_DELETE = 'icon-key-delete'
    KEY_GO = 'icon-key-go'
    LAYERS = 'icon-layers'
    LAYOUT = 'icon-layout'
    LAYOUT_ADD = 'icon-layout-add'
    LAYOUT_CONTENT = 'icon-layout-content'
    LAYOUT_DELETE = 'icon-layout-delete'
    LAYOUT_EDIT = 'icon-layout-edit'
    LAYOUT_ERROR = 'icon-layout-error'
    LAYOUT_HEADER = 'icon-layout-header'
    LAYOUT_LINK = 'icon-layout-link'
    LAYOUT_SIDEBAR = 'icon-layout-sidebar'
    LIGHTBULB = 'icon-lightbulb'
    LIGHTBULB_ADD = 'icon-lightbulb-add'
    LIGHTBULB_DELETE = 'icon-lightbulb-delete'
    LIGHTBULB_OFF = 'icon-lightbulb-off'
    LIGHTNING = 'icon-lightning'
    LIGHTNING_ADD = 'icon-lightning-add'
    LIGHTNING_DELETE = 'icon-lightning-delete'
    LIGHTNING_GO = 'icon-lightning-go'
    LINK = 'icon-link'
    LINK_ADD = 'icon-link-add'
    LINK_BREAK = 'icon-link-break'
    LINK_DELETE = 'icon-link-delete'
    LINK_EDIT = 'icon-link-edit'
    LINK_ERROR = 'icon-link-error'
    LINK_GO = 'icon-link-go'
    LOCK = 'icon-lock'
    LOCK_ADD = 'icon-lock-add'
    LOCK_BREAK = 'icon-lock-break'
    LOCK_DELETE = 'icon-lock-delete'
    LOCK_EDIT = 'icon-lock-edit'
    LOCK_GO = 'icon-lock-go'
    LOCK_OPEN = 'icon-lock-open'
    LORRY = 'icon-lorry'
    LORRY_ADD = 'icon-lorry-add'
    LORRY_DELETE = 'icon-lorry-delete'
    LORRY_ERROR = 'icon-lorry-error'
    LORRY_FLATBED = 'icon-lorry-flatbed'
    LORRY_GO = 'icon-lorry-go'
    LORRY_LINK = 'icon-lorry-link'
    MAGIFIER_ZOOM_OUT = 'icon-magifier-zoom-out'
    MAGNIFIER = 'icon-magnifier'
    MAGNIFIER_ZOOM_IN = 'icon-magnifier-zoom-in'
    MALE = 'icon-male'
    MAP = 'icon-map'
    MAP_ADD = 'icon-map-add'
    MAP_DELETE = 'icon-map-delete'
    MAP_EDIT = 'icon-map-edit'
    MAP_GO = 'icon-map-go'
    MAP_MAGNIFY = 'icon-map-magnify'
    MEDAL_BRONZE_1 = 'icon-medal-bronze-1'
    MEDAL_BRONZE_2 = 'icon-medal-bronze-2'
    MEDAL_BRONZE_3 = 'icon-medal-bronze-3'
    MEDAL_BRONZE_ADD = 'icon-medal-bronze-add'
    MEDAL_BRONZE_DELETE = 'icon-medal-bronze-delete'
    MEDAL_GOLD_1 = 'icon-medal-gold-1'
    MEDAL_GOLD_2 = 'icon-medal-gold-2'
    MEDAL_GOLD_3 = 'icon-medal-gold-3'
    MEDAL_GOLD_ADD = 'icon-medal-gold-add'
    MEDAL_GOLD_DELETE = 'icon-medal-gold-delete'
    MEDAL_SILVER_1 = 'icon-medal-silver-1'
    MEDAL_SILVER_2 = 'icon-medal-silver-2'
    MEDAL_SILVER_3 = 'icon-medal-silver-3'
    MEDAL_SILVER_ADD = 'icon-medal-silver-add'
    MEDAL_SILVER_DELETE = 'icon-medal-silver-delete'
    MONEY = 'icon-money'
    MONEY_ADD = 'icon-money-add'
    MONEY_DELETE = 'icon-money-delete'
    MONEY_DOLLAR = 'icon-money-dollar'
    MONEY_EURO = 'icon-money-euro'
    MONEY_POUND = 'icon-money-pound'
    MONEY_YEN = 'icon-money-yen'
    MONITOR = 'icon-monitor'
    MONITOR_ADD = 'icon-monitor-add'
    MONITOR_DELETE = 'icon-monitor-delete'
    MONITOR_EDIT = 'icon-monitor-edit'
    MONITOR_ERROR = 'icon-monitor-error'
    MONITOR_GO = 'icon-monitor-go'
    MONITOR_LIGHTNING = 'icon-monitor-lightning'
    MONITOR_LINK = 'icon-monitor-link'
    MOUSE = 'icon-mouse'
    MOUSE_ADD = 'icon-mouse-add'
    MOUSE_DELETE = 'icon-mouse-delete'
    MOUSE_ERROR = 'icon-mouse-error'
    MUSIC = 'icon-music'
    NEW = 'icon-new'
    NEWSPAPER = 'icon-newspaper'
    NEWSPAPER_ADD = 'icon-newspaper-add'
    NEWSPAPER_DELETE = 'icon-newspaper-delete'
    NEWSPAPER_GO = 'icon-newspaper-go'
    NEWSPAPER_LINK = 'icon-newspaper-link'
    NOTE = 'icon-note'
    NOTE_ADD = 'icon-note-add'
    NOTE_DELETE = 'icon-note-delete'
    NOTE_EDIT = 'icon-note-edit'
    NOTE_ERROR = 'icon-note-error'
    NOTE_GO = 'icon-note-go'
    OVERLAYS = 'icon-overlays'
    PACKAGE = 'icon-package'
    PACKAGE_PY = 'icon-package-py'
    PACKAGE_ADD = 'icon-package-add'
    PACKAGE_DELETE = 'icon-package-delete'
    PACKAGE_GO = 'icon-package-go'
    PACKAGE_GREEN = 'icon-package-green'
    PACKAGE_LINK = 'icon-package-link'
    PAGE = 'icon-page'
    PAGE_ADD = 'icon-page-add'
    PAGE_ATTACH = 'icon-page-attach'
    PAGE_CODE = 'icon-page-code'
    PAGE_COPY = 'icon-page-copy'
    PAGE_DELETE = 'icon-page-delete'
    PAGE_EDIT = 'icon-page-edit'
    PAGE_ERROR = 'icon-page-error'
    PAGE_EXCEL = 'icon-page-excel'
    PAGE_FIND = 'icon-page-find'
    PAGE_GEAR = 'icon-page-gear'
    PAGE_GO = 'icon-page-go'
    PAGE_GREEN = 'icon-page-green'
    PAGE_KEY = 'icon-page-key'
    PAGE_LIGHTNING = 'icon-page-lightning'
    PAGE_LINK = 'icon-page-link'
    PAGE_PAINTBRUSH = 'icon-page-paintbrush'
    PAGE_PASTE = 'icon-page-paste'
    PAGE_RED = 'icon-page-red'
    PAGE_REFRESH = 'icon-page-refresh'
    PAGE_SAVE = 'icon-page-save'
    PAGE_WHITE = 'icon-page-white'
    PAGE_WHITE_ACROBAT = 'icon-page-white-acrobat'
    PAGE_WHITE_ACTIONSCRIPT = 'icon-page-white-actionscript'
    PAGE_WHITE_ADD = 'icon-page-white-add'
    PAGE_WHITE_C = 'icon-page-white-c'
    PAGE_WHITE_CAMERA = 'icon-page-white-camera'
    PAGE_WHITE_CD = 'icon-page-white-cd'
    PAGE_WHITE_CODE = 'icon-page-white-code'
    PAGE_WHITE_CODE_RED = 'icon-page-white-code-red'
    PAGE_WHITE_COLDFUSION = 'icon-page-white-coldfusion'
    PAGE_WHITE_COMPRESSED = 'icon-page-white-compressed'
    PAGE_WHITE_COPY = 'icon-page-white-copy'
    PAGE_WHITE_CPLUSPLUS = 'icon-page-white-cplusplus'
    PAGE_WHITE_CSHARP = 'icon-page-white-csharp'
    PAGE_WHITE_CUP = 'icon-page-white-cup'
    PAGE_WHITE_DATABASE = 'icon-page-white-database'
    PAGE_WHITE_DELETE = 'icon-page-white-delete'
    PAGE_WHITE_DVD = 'icon-page-white-dvd'
    PAGE_WHITE_EDIT = 'icon-page-white-edit'
    PAGE_WHITE_ERROR = 'icon-page-white-error'
    PAGE_WHITE_EXCEL = 'icon-page-white-excel'
    PAGE_WHITE_FIND = 'icon-page-white-find'
    PAGE_WHITE_FLASH = 'icon-page-white-flash'
    PAGE_WHITE_FREEHAND = 'icon-page-white-freehand'
    PAGE_WHITE_GEAR = 'icon-page-white-gear'
    PAGE_WHITE_GET = 'icon-page-white-get'
    PAGE_WHITE_GO = 'icon-page-white-go'
    PAGE_WHITE_H = 'icon-page-white-h'
    PAGE_WHITE_HORIZONTAL = 'icon-page-white-horizontal'
    PAGE_WHITE_KEY = 'icon-page-white-key'
    PAGE_WHITE_LIGHTNING = 'icon-page-white-lightning'
    PAGE_WHITE_LINK = 'icon-page-white-link'
    PAGE_WHITE_MAGNIFY = 'icon-page-white-magnify'
    PAGE_WHITE_MEDAL = 'icon-page-white-medal'
    PAGE_WHITE_OFFICE = 'icon-page-white-office'
    PAGE_WHITE_PAINT = 'icon-page-white-paint'
    PAGE_WHITE_PAINTBRUSH = 'icon-page-white-paintbrush'
    PAGE_WHITE_PASTE = 'icon-page-white-paste'
    PAGE_WHITE_PHP = 'icon-page-white-php'
    PAGE_WHITE_PICTURE = 'icon-page-white-picture'
    PAGE_WHITE_POWERPOINT = 'icon-page-white-powerpoint'
    PAGE_WHITE_PUT = 'icon-page-white-put'
    PAGE_WHITE_PY = 'icon-page-white-py'
    PAGE_WHITE_JS = 'icon-page-white-js'
    PAGE_WHITE_RUBY = 'icon-page-white-ruby'
    PAGE_WHITE_STACK = 'icon-page-white-stack'
    PAGE_WHITE_STAR = 'icon-page-white-star'
    PAGE_WHITE_SWOOSH = 'icon-page-white-swoosh'
    PAGE_WHITE_TEXT = 'icon-page-white-text'
    PAGE_WHITE_TEXT_WIDTH = 'icon-page-white-text-width'
    PAGE_WHITE_TUX = 'icon-page-white-tux'
    PAGE_WHITE_VECTOR = 'icon-page-white-vector'
    PAGE_WHITE_VISUALSTUDIO = 'icon-page-white-visualstudio'
    PAGE_WHITE_WIDTH = 'icon-page-white-width'
    PAGE_WHITE_WORD = 'icon-page-white-word'
    PAGE_WHITE_WORLD = 'icon-page-white-world'
    PAGE_WHITE_WRENCH = 'icon-page-white-wrench'
    PAGE_WHITE_ZIP = 'icon-page-white-zip'
    PAGE_WORD = 'icon-page-word'
    PAGE_WORLD = 'icon-page-world'
    PAINTBRUSH = 'icon-paintbrush'
    PAINTCAN = 'icon-paintcan'
    PALETTE = 'icon-palette'
    PASTE_PLAIN = 'icon-paste-plain'
    PASTE_WORD = 'icon-paste-word'
    PENCIL = 'icon-pencil'
    PENCIL_ADD = 'icon-pencil-add'
    PENCIL_DELETE = 'icon-pencil-delete'
    PENCIL_GO = 'icon-pencil-go'
    PHONE = 'icon-phone'
    PHONE_ADD = 'icon-phone-add'
    PHONE_DELETE = 'icon-phone-delete'
    PHONE_SOUND = 'icon-phone-sound'
    PHOTO = 'icon-photo'
    PHOTOS = 'icon-photos'
    PHOTO_ADD = 'icon-photo-add'
    PHOTO_DELETE = 'icon-photo-delete'
    PHOTO_LINK = 'icon-photo-link'
    PICTURE = 'icon-picture'
    PICTURES = 'icon-pictures'
    PICTURE_ADD = 'icon-picture-add'
    PICTURE_DELETE = 'icon-picture-delete'
    PICTURE_EDIT = 'icon-picture-edit'
    PICTURE_EMPTY = 'icon-picture-empty'
    PICTURE_ERROR = 'icon-picture-error'
    PICTURE_GO = 'icon-picture-go'
    PICTURE_KEY = 'icon-picture-key'
    PICTURE_LINK = 'icon-picture-link'
    PICTURE_SAVE = 'icon-picture-save'
    PILCROW = 'icon-pilcrow'
    PILL = 'icon-pill'
    PILL_ADD = 'icon-pill-add'
    PILL_DELETE = 'icon-pill-delete'
    PILL_GO = 'icon-pill-go'
    PLUGIN = 'icon-plugin'
    PLUGIN_ADD = 'icon-plugin-add'
    PLUGIN_DELETE = 'icon-plugin-delete'
    PLUGIN_DISABLED = 'icon-plugin-disabled'
    PLUGIN_EDIT = 'icon-plugin-edit'
    PLUGIN_ERROR = 'icon-plugin-error'
    PLUGIN_GO = 'icon-plugin-go'
    PLUGIN_LINK = 'icon-plugin-link'
    PRINTER = 'icon-printer'
    PRINTER_ADD = 'icon-printer-add'
    PRINTER_DELETE = 'icon-printer-delete'
    PRINTER_EMPTY = 'icon-printer-empty'
    PRINTER_ERROR = 'icon-printer-error'
    RAINBOW = 'icon-rainbow'
    REPORT = 'icon-report'
    REPORT_ADD = 'icon-report-add'
    REPORT_DELETE = 'icon-report-delete'
    REPORT_DISK = 'icon-report-disk'
    REPORT_EDIT = 'icon-report-edit'
    REPORT_GO = 'icon-report-go'
    REPORT_KEY = 'icon-report-key'
    REPORT_LINK = 'icon-report-link'
    REPORT_MAGNIFY = 'icon-report-magnify'
    REPORT_PICTURE = 'icon-report-picture'
    REPORT_USER = 'icon-report-user'
    REPORT_WORD = 'icon-report-word'
    RESULTSET_FIRST = 'icon-resultset-first'
    RESULTSET_LAST = 'icon-resultset-last'
    RESULTSET_NEXT = 'icon-resultset-next'
    RESULTSET_PREVIOUS = 'icon-resultset-previous'
    ROSETTE = 'icon-rosette'
    RSS = 'icon-rss'
    RSS_ADD = 'icon-rss-add'
    RSS_DELETE = 'icon-rss-delete'
    RSS_GO = 'icon-rss-go'
    RSS_VALID = 'icon-rss-valid'
    RUBY = 'icon-ruby'
    RUBY_ADD = 'icon-ruby-add'
    RUBY_DELETE = 'icon-ruby-delete'
    RUBY_GEAR = 'icon-ruby-gear'
    RUBY_GET = 'icon-ruby-get'
    RUBY_GO = 'icon-ruby-go'
    RUBY_KEY = 'icon-ruby-key'
    RUBY_LINK = 'icon-ruby-link'
    RUBY_PUT = 'icon-ruby-put'
    SCRIPT = 'icon-script'
    SCRIPT_ADD = 'icon-script-add'
    SCRIPT_CODE = 'icon-script-code'
    SCRIPT_CODE_RED = 'icon-script-code-red'
    SCRIPT_DELETE = 'icon-script-delete'
    SCRIPT_EDIT = 'icon-script-edit'
    SCRIPT_ERROR = 'icon-script-error'
    SCRIPT_GEAR = 'icon-script-gear'
    SCRIPT_GO = 'icon-script-go'
    SCRIPT_KEY = 'icon-script-key'
    SCRIPT_LIGHTNING = 'icon-script-lightning'
    SCRIPT_LINK = 'icon-script-link'
    SCRIPT_PALETTE = 'icon-script-palette'
    SCRIPT_SAVE = 'icon-script-save'
    SERVER = 'icon-server'
    SERVER_ADD = 'icon-server-add'
    SERVER_CHART = 'icon-server-chart'
    SERVER_COMPRESSED = 'icon-server-compressed'
    SERVER_CONNECT = 'icon-server-connect'
    SERVER_DATABASE = 'icon-server-database'
    SERVER_DELETE = 'icon-server-delete'
    SERVER_EDIT = 'icon-server-edit'
    SERVER_ERROR = 'icon-server-error'
    SERVER_GO = 'icon-server-go'
    SERVER_KEY = 'icon-server-key'
    SERVER_LIGHTNING = 'icon-server-lightning'
    SERVER_LINK = 'icon-server-link'
    SERVER_UNCOMPRESSED = 'icon-server-uncompressed'
    SHADING = 'icon-shading'
    SHAPE_ALIGN_BOTTOM = 'icon-shape-align-bottom'
    SHAPE_ALIGN_CENTER = 'icon-shape-align-center'
    SHAPE_ALIGN_LEFT = 'icon-shape-align-left'
    SHAPE_ALIGN_MIDDLE = 'icon-shape-align-middle'
    SHAPE_ALIGN_RIGHT = 'icon-shape-align-right'
    SHAPE_ALIGN_TOP = 'icon-shape-align-top'
    SHAPE_FLIP_HORIZONTAL = 'icon-shape-flip-horizontal'
    SHAPE_FLIP_VERTICAL = 'icon-shape-flip-vertical'
    SHAPE_GROUP = 'icon-shape-group'
    SHAPE_HANDLES = 'icon-shape-handles'
    SHAPE_MOVE_BACK = 'icon-shape-move-back'
    SHAPE_MOVE_BACKWARDS = 'icon-shape-move-backwards'
    SHAPE_MOVE_FORWARDS = 'icon-shape-move-forwards'
    SHAPE_MOVE_FRONT = 'icon-shape-move-front'
    SHAPE_ROTATE_ANTICLOCKWISE = 'icon-shape-rotate-anticlockwise'
    SHAPE_ROTATE_CLOCKWISE = 'icon-shape-rotate-clockwise'
    SHAPE_SQUARE = 'icon-shape-square'
    SHAPE_SQUARE_ADD = 'icon-shape-square-add'
    SHAPE_SQUARE_DELETE = 'icon-shape-square-delete'
    SHAPE_SQUARE_EDIT = 'icon-shape-square-edit'
    SHAPE_SQUARE_ERROR = 'icon-shape-square-error'
    SHAPE_SQUARE_GO = 'icon-shape-square-go'
    SHAPE_SQUARE_KEY = 'icon-shape-square-key'
    SHAPE_SQUARE_LINK = 'icon-shape-square-link'
    SHAPE_UNGROUP = 'icon-shape-ungroup'
    SHIELD = 'icon-shield'
    SHIELD_ADD = 'icon-shield-add'
    SHIELD_DELETE = 'icon-shield-delete'
    SHIELD_GO = 'icon-shield-go'
    SITEMAP = 'icon-sitemap'
    SITEMAP_COLOR = 'icon-sitemap-color'
    SOUND = 'icon-sound'
    SOUND_ADD = 'icon-sound-add'
    SOUND_DELETE = 'icon-sound-delete'
    SOUND_LOW = 'icon-sound-low'
    SOUND_MUTE = 'icon-sound-mute'
    SOUND_NONE = 'icon-sound-none'
    SPELLCHECK = 'icon-spellcheck'
    SPORT_8BALL = 'icon-sport-8ball'
    SPORT_BASKETBALL = 'icon-sport-basketball'
    SPORT_FOOTBALL = 'icon-sport-football'
    SPORT_GOLF = 'icon-sport-golf'
    SPORT_RAQUET = 'icon-sport-raquet'
    SPORT_SHUTTLECOCK = 'icon-sport-shuttlecock'
    SPORT_SOCCER = 'icon-sport-soccer'
    SPORT_TENNIS = 'icon-sport-tennis'
    STAR = 'icon-star'
    STATUS_AWAY = 'icon-status-away'
    STATUS_BUSY = 'icon-status-busy'
    STATUS_OFFLINE = 'icon-status-offline'
    STATUS_ONLINE = 'icon-status-online'
    STOP = 'icon-stop'
    STYLE = 'icon-style'
    STYLE_ADD = 'icon-style-add'
    STYLE_DELETE = 'icon-style-delete'
    STYLE_EDIT = 'icon-style-edit'
    STYLE_GO = 'icon-style-go'
    SUM = 'icon-sum'
    TAB = 'icon-tab'
    TABLE = 'icon-table'
    TABLE_ADD = 'icon-table-add'
    TABLE_DELETE = 'icon-table-delete'
    TABLE_EDIT = 'icon-table-edit'
    TABLE_ERROR = 'icon-table-error'
    TABLE_GEAR = 'icon-table-gear'
    TABLE_GO = 'icon-table-go'
    TABLE_KEY = 'icon-table-key'
    TABLE_LIGHTNING = 'icon-table-lightning'
    TABLE_LINK = 'icon-table-link'
    TABLE_MULTIPLE = 'icon-table-multiple'
    TABLE_REFRESH = 'icon-table-refresh'
    TABLE_RELATIONSHIP = 'icon-table-relationship'
    TABLE_ROW_DELETE = 'icon-table-row-delete'
    TABLE_ROW_INSERT = 'icon-table-row-insert'
    TABLE_SAVE = 'icon-table-save'
    TABLE_SORT = 'icon-table-sort'
    TAB_ADD = 'icon-tab-add'
    TAB_DELETE = 'icon-tab-delete'
    TAB_EDIT = 'icon-tab-edit'
    TAB_GO = 'icon-tab-go'
    TAG = 'icon-tag'
    TAG_BLUE = 'icon-tag-blue'
    TAG_BLUE_ADD = 'icon-tag-blue-add'
    TAG_BLUE_DELETE = 'icon-tag-blue-delete'
    TAG_BLUE_EDIT = 'icon-tag-blue-edit'
    TAG_GREEN = 'icon-tag-green'
    TAG_ORANGE = 'icon-tag-orange'
    TAG_PINK = 'icon-tag-pink'
    TAG_PURPLE = 'icon-tag-purple'
    TAG_RED = 'icon-tag-red'
    TAG_YELLOW = 'icon-tag-yellow'
    TELEPHONE = 'icon-telephone'
    TELEPHONE_ADD = 'icon-telephone-add'
    TELEPHONE_DELETE = 'icon-telephone-delete'
    TELEPHONE_EDIT = 'icon-telephone-edit'
    TELEPHONE_ERROR = 'icon-telephone-error'
    TELEPHONE_GO = 'icon-telephone-go'
    TELEPHONE_KEY = 'icon-telephone-key'
    TELEPHONE_LINK = 'icon-telephone-link'
    TELEVISION = 'icon-television'
    TELEVISION_ADD = 'icon-television-add'
    TELEVISION_DELETE = 'icon-television-delete'
    TEXTFIELD = 'icon-textfield'
    TEXTFIELD_ADD = 'icon-textfield-add'
    TEXTFIELD_DELETE = 'icon-textfield-delete'
    TEXTFIELD_KEY = 'icon-textfield-key'
    TEXTFIELD_RENAME = 'icon-textfield-rename'
    TEXT_ALIGN_CENTER = 'icon-text-align-center'
    TEXT_ALIGN_JUSTIFY = 'icon-text-align-justify'
    TEXT_ALIGN_LEFT = 'icon-text-align-left'
    TEXT_ALIGN_RIGHT = 'icon-text-align-right'
    TEXT_ALLCAPS = 'icon-text-allcaps'
    TEXT_BOLD = 'icon-text-bold'
    TEXT_COLUMNS = 'icon-text-columns'
    TEXT_DROPCAPS = 'icon-text-dropcaps'
    TEXT_HEADING_1 = 'icon-text-heading-1'
    TEXT_HEADING_2 = 'icon-text-heading-2'
    TEXT_HEADING_3 = 'icon-text-heading-3'
    TEXT_HEADING_4 = 'icon-text-heading-4'
    TEXT_HEADING_5 = 'icon-text-heading-5'
    TEXT_HEADING_6 = 'icon-text-heading-6'
    TEXT_HORIZONTALRULE = 'icon-text-horizontalrule'
    TEXT_INDENT = 'icon-text-indent'
    TEXT_INDENT_REMOVE = 'icon-text-indent-remove'
    TEXT_ITALIC = 'icon-text-italic'
    TEXT_KERNING = 'icon-text-kerning'
    TEXT_LETTERSPACING = 'icon-text-letterspacing'
    TEXT_LETTER_OMEGA = 'icon-text-letter-omega'
    TEXT_LINESPACING = 'icon-text-linespacing'
    TEXT_LIST_BULLETS = 'icon-text-list-bullets'
    TEXT_LIST_NUMBERS = 'icon-text-list-numbers'
    TEXT_LOWERCASE = 'icon-text-lowercase'
    TEXT_PADDING_BOTTOM = 'icon-text-padding-bottom'
    TEXT_PADDING_LEFT = 'icon-text-padding-left'
    TEXT_PADDING_RIGHT = 'icon-text-padding-right'
    TEXT_PADDING_TOP = 'icon-text-padding-top'
    TEXT_REPLACE = 'icon-text-replace'
    TEXT_SIGNATURE = 'icon-text-signature'
    TEXT_SMALLCAPS = 'icon-text-smallcaps'
    TEXT_STRIKETHROUGH = 'icon-text-strikethrough'
    TEXT_SUBSCRIPT = 'icon-text-subscript'
    TEXT_SUPERSCRIPT = 'icon-text-superscript'
    TEXT_UNDERLINE = 'icon-text-underline'
    TEXT_UPPERCASE = 'icon-text-uppercase'
    THUMB_DOWN = 'icon-thumb-down'
    THUMB_UP = 'icon-thumb-up'
    TICK = 'icon-tick'
    TIME = 'icon-time'
    TIMELINE_MARKER = 'icon-timeline-marker'
    TIME_ADD = 'icon-time-add'
    TIME_DELETE = 'icon-time-delete'
    TIME_GO = 'icon-time-go'
    TRANSMIT = 'icon-transmit'
    TRANSMIT_ADD = 'icon-transmit-add'
    TRANSMIT_BLUE = 'icon-transmit-blue'
    TRANSMIT_DELETE = 'icon-transmit-delete'
    TRANSMIT_EDIT = 'icon-transmit-edit'
    TRANSMIT_ERROR = 'icon-transmit-error'
    TRANSMIT_GO = 'icon-transmit-go'
    TUX = 'icon-tux'
    USER = 'icon-user'
    USER_ADD = 'icon-user-add'
    USER_COMMENT = 'icon-user-comment'
    USER_DELETE = 'icon-user-delete'
    USER_EDIT = 'icon-user-edit'
    USER_FEMALE = 'icon-user-female'
    USER_GO = 'icon-user-go'
    USER_GRAY = 'icon-user-gray'
    USER_GREEN = 'icon-user-green'
    USER_ORANGE = 'icon-user-orange'
    USER_RED = 'icon-user-red'
    USER_SUIT = 'icon-user-suit'
    VCARD = 'icon-vcard'
    VCARD_ADD = 'icon-vcard-add'
    VCARD_DELETE = 'icon-vcard-delete'
    VCARD_EDIT = 'icon-vcard-edit'
    VECTOR = 'icon-vector'
    VECTOR_ADD = 'icon-vector-add'
    VECTOR_DELETE = 'icon-vector-delete'
    WAND = 'icon-wand'
    WEATHER_CLOUDS = 'icon-weather-clouds'
    WEATHER_CLOUDY = 'icon-weather-cloudy'
    WEATHER_LIGHTNING = 'icon-weather-lightning'
    WEATHER_RAIN = 'icon-weather-rain'
    WEATHER_SNOW = 'icon-weather-snow'
    WEATHER_SUN = 'icon-weather-sun'
    WEBCAM = 'icon-webcam'
    WEBCAM_ADD = 'icon-webcam-add'
    WEBCAM_DELETE = 'icon-webcam-delete'
    WEBCAM_ERROR = 'icon-webcam-error'
    WORLD = 'icon-world'
    WORLD_ADD = 'icon-world-add'
    WORLD_DELETE = 'icon-world-delete'
    WORLD_EDIT = 'icon-world-edit'
    WORLD_GO = 'icon-world-go'
    WORLD_LINK = 'icon-world-link'
    WRENCH = 'icon-wrench'
    WRENCH_ORANGE = 'icon-wrench-orange'
    XHTML = 'icon-xhtml'
    XHTML_ADD = 'icon-xhtml-add'
    XHTML_DELETE = 'icon-xhtml-delete'
    XHTML_GO = 'icon-xhtml-go'
    XHTML_VALID = 'icon-xhtml-valid'
    ZOOM = 'icon-zoom'
    ZOOM_IN = 'icon-zoom-in'
    ZOOM_OUT = 'icon-zoom-out'
